==> biodiv_4_3.zip: plugins/biodiv/lang/campagne_fr.php <==
<?php

/*******************************************************************************\
 * BIODIV, plugin et squelette pour SPIP - https://www.spip.net/               *
 *         dédié à la gestion d'observations naturalistes                      *
 *                                                                             *
 *         Copyright (C) 2008-2020 Renaud LAURETTE                             *
 *                                                                             *
 * BIODIV a été développé initialement pour le projet Biodiv.Balma de l'APCVEB *
 * (Association de Protection du Cadre de Vie et de l'Environnement balmanais) * 
 *     voir Biodiv.Balma : https://balma.biodiv.fr/                            *
 *     voir APCVEB : http://apcveb.free.fr/                                    *
 *                                                                             *
 *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.         *
 *  Pour plus de détails voir les fichier COPYING.txt et LICENCE-BIODIV.md     *
\*******************************************************************************/

// This is a SPIP language file  --  Ceci est un fichier langue de SPIP

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'ajouter_lien_campagne' => 'Ajouter cette campagne',

	
	// C
	'champ_debut_explication' => 'Premier jour de la campagne',
	'champ_debut_label' => 'Début',
	'champ_fin_explication' => 'Dernier jour de la campagne',
	'champ_fin_label' => 'Fin',
	'champ_texte_explication' => 'Description de la campagne',
	'champ_texte_label' => 'Texte',
	'champ_titre_label' => 'Titre',
	'confirmer_supprimer_campagne' => 'Confirmez-vous la suppression de cette campagne ?',

	// I
	'icone_creer_campagne' => 'Créer une campagne',
	'icone_modifier_campagne' => 'Modifier cette campagne',
	'info_1_campagne' => 'Une campagne',
	'info_aucun_campagne' => 'Aucune campagne',
	'info_biodiv_campagnes_auteur' => 'Les campagnes de cet auteur',
	'info_nb_biodiv_campagnes' => '@nb@ campagnes',

	// P
	'perimetre_absent' => 'Aucun périmètre défini pour cette campagne',
	
	// R
	'retirer_lien_campagne' => 'Retirer cette campagne',
	'retirer_tous_liens_biodiv_campagnes' => 'Retirer toutes les campagnes',

	// S
	'supprimer_campagne' => 'Supprimer cette campagne',

	// T
	'texte_ajouter_campagne' => 'Ajouter une campagne',
	'texte_changer_statut_campagne' => 'Cette campagne est :',
	'texte_creer_associer_campagne' => 'Créer et associer une campagne',
	'texte_definir_comme_traduction_campagne' => 'Cette campagne est une traduction de la campagne numéro :',
	'titre_biodiv_campagnes' => 'Campagnes',
	'titre_biodiv_campagnes_rubrique' => 'Campagnes de la rubrique',
	'titre_campagne' => 'Campagne',
	'titre_langue_campagne' => 'Langue de cette campagne',
	'titre_logo_campagne' => 'Logo de cette campagne',
	'titre_objets_lies_campagne' => 'Liés à cette campagne',
);

==> biodiv_4_4_0.zip: plugins/biodiv/lang/campagne_fr.php <==
<?php

/*******************************************************************************\
 * BIODIV, plugin et squelette pour SPIP - https://www.spip.net/               *
 *         dédié à la gestion d'observations naturalistes                      *
 *                                                                             *
 *         Copyright (C) 2008-2020 Renaud LAURETTE                             *
 *                                                                             *
 * BIODIV a été développé initialement pour le projet Biodiv.Balma de l'APCVEB *
 * (Association de Protection du Cadre de Vie et de l'Environnement balmanais) * 
 *     voir Biodiv.Balma : https://balma.biodiv.fr/                            *
 *     voir APCVEB : http://apcveb.free.fr/                                    *
 *                                                                             *
 *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.         *
 *  Pour plus de détails voir les fichier COPYING.txt et LICENCE-BIODIV.md     *
\*******************************************************************************/

// This is a SPIP language file  --  Ceci est un fichier langue de SPIP

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'ajouter_lien_campagne' => 'Ajouter cette campagne',

	
	// C
	'champ_debut_explication' => 'Premier jour de la campagne',
	'champ_debut_label' => 'Début',
	'champ_fin_explication' => 'Dernier jour de la campagne',
	'champ_fin_label' => 'Fin',
	'champ_id_campagne_label' => 'Identifiant de la campagne',
	'champ_texte_explication' => 'Description de la campagne',
	'champ_texte_label' => 'Texte',
	'champ_titre_label' => 'Titre',
	'confirmer_supprimer_campagne' => 'Confirmez-vous la suppression de cette campagne ?',

	// Sibactu
	'cfg_titre_actualite' => 'Titre pour les campagnes',
	'liste_actualite' => 'Campagnes',	
	
	// I
	'icone_creer_campagne' => 'Créer une campagne',
	'icone_modifier_campagne' => 'Modifier cette campagne',
	'info_1_campagne' => 'Une campagne',
	'info_aucun_campagne' => 'Aucune campagne',
	'info_biodiv_campagnes_auteur' => 'Les campagnes de cet auteur',
	'info_nb_biodiv_campagnes' => '@nb@ campagnes',

	// P
	'perimetre_absent' => 'Aucun périmètre défini pour cette campagne',
	
	// R
	'retirer_lien_campagne' => 'Retirer cette campagne',
	'retirer_tous_liens_biodiv_campagnes' => 'Retirer toutes les campagnes',

	// S
	'supprimer_campagne' => 'Supprimer cette campagne',

	// T
	'texte_ajouter_campagne' => 'Ajouter une campagne',
	'texte_changer_statut_campagne' => 'Cette campagne est :',
	'texte_creer_associer_campagne' => 'Créer et associer une campagne',
	'texte_definir_comme_traduction_campagne' => 'Cette campagne est une traduction de la campagne numéro :',
	'titre_biodiv_campagnes' => 'Campagnes',
	'titre_biodiv_campagnes_rubrique' => 'Campagnes de la rubrique',
	'titre_campagne' => 'Campagne',
	'titre_langue_campagne' => 'Langue de cette campagne',
	'titre_logo_campagne' => 'Logo de cette campagne',
	'titre_objets_lies_campagne' => 'Liés à cette campagne',
	
);
